@@ -20,7 +20,7 @@
 #define TNTDB_BITS_STATEMENT_H
 
 #include <string>
-#include <tntdb/smartptr.h>
+#include <cxxtools/smartptr.h>
 #include <tntdb/iface/istatement.h>
 #include <tntdb/date.h>
 #include <tntdb/time.h>
@@ -52,7 +52,7 @@ namespace tntdb
       typedef IStatement::size_type size_type;
 
     private:
-      SmartPtr<IStatement, InternalRefCounted> stmt;
+      cxxtools::SmartPtr<IStatement> stmt;
 
     public:
       Statement(IStatement* stmt_ = 0)
@@ -84,6 +84,31 @@ namespace tntdb
        */
       Statement& setUnsigned(const std::string& col, unsigned data)
         { stmt->setUnsigned(col, data); return *this; }
+      /**
+       * Sets the hostvariable with the given name to a int32_t value.
+       */
+      Statement& setInt32(const std::string& col, int32_t data)
+        { stmt->setInt32(col, data); return *this; }
+      /**
+       * Sets the hostvariable with the given name to a uint32_t value.
+       */
+      Statement& setUnsigned32(const std::string& col, uint32_t data)
+        { stmt->setUnsigned32(col, data); return *this; }
+      /**
+       * Sets the hostvariable with the given name to a int64_t value.
+       */
+      Statement& setInt64(const std::string& col, int64_t data)
+        { stmt->setInt64(col, data); return *this; }
+      /**
+       * Sets the hostvariable with the given name to a uint64_t value.
+       */
+      Statement& setUnsigned64(const std::string& col, uint64_t data)
+        { stmt->setUnsigned64(col, data); return *this; }
+      /**
+       * Sets the hostvariable with the given name to a Decimal.
+       */
+      Statement& setDecimal(const std::string& col, const Decimal& data)
+        { stmt->setDecimal(col, data); return *this; }
       /**
        * Sets the hostvariable with the given name to a float value.
        */
@@ -111,6 +136,8 @@ namespace tntdb
       Statement& setString(const std::string& col, const char* data)
         { data == 0 ? stmt->setNull(col)
                     : stmt->setString(col, data); return *this; }
+      Statement& setBlob(const std::string& col, const Blob& data)
+        { stmt->setBlob(col, data); return *this; }
       /**
        * Sets the hostvariable with the given name to a date value.
        */
@@ -161,6 +188,10 @@ namespace tntdb
       Statement& set(const std::string& col, const Datetime& data)
         { data.isNull() ? stmt->setNull(col)
                         : stmt->setDatetime(col, data); return *this; }
+      Statement& set(const std::string& col, const Decimal& data)
+        { stmt->setDecimal(col, data); return *this; }
+      Statement& set(const std::string& col, const Blob& data)
+        { stmt->setBlob(col, data); return *this; }
       //@}
 
       /// statement-execution-methods
