@@ -19,13 +19,13 @@
 #ifndef TNTDB_IFACE_ICURSOR_H
 #define TNTDB_IFACE_ICURSOR_H
 
-#include <tntdb/refcounted.h>
+#include <cxxtools/refcounted.h>
 
 namespace tntdb
 {
   class Row;
 
-  class ICursor : public RefCounted
+  class ICursor : public cxxtools::RefCounted
   {
     public:
       virtual Row fetch() = 0;
