@@ -19,20 +19,22 @@
 #ifndef TNTDB_IFACE_IROW_H
 #define TNTDB_IFACE_IROW_H
 
-#include <tntdb/refcounted.h>
+#include <cxxtools/refcounted.h>
+#include <string>
 
 namespace tntdb
 {
   class Value;
 
   /// common interface for row-types
-  class IRow : public RefCounted
+  class IRow : public cxxtools::RefCounted
   {
     public:
       typedef unsigned size_type;
 
       virtual size_type size() const = 0;
-      virtual Value getValue(size_type field_num) const = 0;
+      virtual Value getValueByNumber(size_type field_num) const = 0;
+      virtual Value getValueByName(const std::string& field_name) const = 0;
   };
 }
 
