@@ -19,7 +19,7 @@
 #ifndef TNTDB_IFACE_ISTATEMENT_H
 #define TNTDB_IFACE_ISTATEMENT_H
 
-#include <tntdb/refcounted.h>
+#include <cxxtools/refcounted.h>
 #include <string>
 
 namespace tntdb
@@ -30,9 +30,11 @@ namespace tntdb
   class Date;
   class Time;
   class Datetime;
+  class Decimal;
   class ICursor;
+  class Blob;
 
-  class IStatement : public RefCounted
+  class IStatement : public cxxtools::RefCounted
   {
     public:
       typedef unsigned size_type;
@@ -43,10 +45,16 @@ namespace tntdb
       virtual void setBool(const std::string& col, bool data) = 0;
       virtual void setInt(const std::string& col, int data) = 0;
       virtual void setUnsigned(const std::string& col, unsigned data) = 0;
+      virtual void setInt32(const std::string& col, int32_t data) = 0;
+      virtual void setUnsigned32(const std::string& col, uint32_t data) = 0;
+      virtual void setInt64(const std::string& col, int64_t data) = 0;
+      virtual void setUnsigned64(const std::string& col, uint64_t data) = 0;
+      virtual void setDecimal(const std::string& col, const Decimal& data) = 0;
       virtual void setFloat(const std::string& col, float data) = 0;
       virtual void setDouble(const std::string& col, double data) = 0;
       virtual void setChar(const std::string& col, char data) = 0;
       virtual void setString(const std::string& col, const std::string& data) = 0;
+      virtual void setBlob(const std::string& col, const Blob& data) = 0;
       virtual void setDate(const std::string& col, const Date& data) = 0;
       virtual void setTime(const std::string& col, const Time& data) = 0;
       virtual void setDatetime(const std::string& col, const Datetime& data) = 0;
