@@ -19,7 +19,7 @@
 #ifndef TNTDB_IFACE_IVALUE_H
 #define TNTDB_IFACE_IVALUE_H
 
-#include <tntdb/refcounted.h>
+#include <cxxtools/refcounted.h>
 #include <string>
 
 namespace tntdb
@@ -27,19 +27,27 @@ namespace tntdb
   class Date;
   class Time;
   class Datetime;
-
+  class Decimal;
+  class Blob;
+  
   /// common inteface for resultvalues
-  class IValue : public RefCounted
+  class IValue : public cxxtools::RefCounted
   {
     public:
       virtual bool isNull() const = 0;
       virtual bool getBool() const = 0;
       virtual int getInt() const = 0;
       virtual unsigned getUnsigned() const = 0;
+      virtual int32_t getInt32() const = 0;
+      virtual uint32_t getUnsigned32() const = 0;
+      virtual int64_t getInt64() const = 0;
+      virtual uint64_t getUnsigned64() const = 0;
+      virtual Decimal getDecimal() const = 0;
       virtual float getFloat() const = 0;
       virtual double getDouble() const = 0;
       virtual char getChar() const = 0;
-      virtual std::string getString() const = 0;
+      virtual void getString(std::string& ret) const = 0;
+      virtual void getBlob(Blob& ret) const = 0;
       virtual Date getDate() const = 0;
       virtual Time getTime() const = 0;
       virtual Datetime getDatetime() const = 0;
