@@ -34,7 +34,8 @@ namespace tntdb
           { }
 
         size_type size() const;
-        Value getValue(size_type field_num) const;
+        Value getValueByNumber(size_type field_num) const;
+        Value getValueByName(const std::string& field_name) const;
     };
   }
 }
