@@ -20,6 +20,7 @@
 #define TNTDB_MYSQL_IMPL_SQLSTATEMENT_H
 
 #include <tntdb/iface/istatement.h>
+#include <tntdb/iface/irow.h>
 #include <tntdb/mysql/bindvalues.h>
 #include <tntdb/connection.h>
 #include <map>
@@ -40,6 +41,8 @@ namespace tntdb
         MYSQL_STMT* stmt;
         MYSQL_RES* metadata;
 
+        cxxtools::SmartPtr<IRow> fetchRow(MYSQL_FIELD* fields, unsigned field_count);
+
       public:
         Statement(const tntdb::Connection& conn, MYSQL* mysql,
           const std::string& query);
@@ -52,10 +55,16 @@ namespace tntdb
         void setBool(const std::string& col, bool data);
         void setInt(const std::string& col, int data);
         void setUnsigned(const std::string& col, unsigned data);
+        void setInt32(const std::string& col, int32_t data);
+        void setUnsigned32(const std::string& col, uint32_t data);
+        void setInt64(const std::string& col, int64_t data);
+        void setUnsigned64(const std::string& col, uint64_t data);
+        void setDecimal(const std::string& col, const Decimal& data);
         void setFloat(const std::string& col, float data);
         void setDouble(const std::string& col, double data);
         void setChar(const std::string& col, char data);
         void setString(const std::string& col, const std::string& data);
+        void setBlob(const std::string& col, const Blob& data);
         void setDate(const std::string& col, const Date& data);
         void setTime(const std::string& col, const Time& data);
         void setDatetime(const std::string& col, const Datetime& data);
