@@ -33,7 +33,7 @@ namespace tntdb
   }
 }
 
-TNTDB_CONNECTIONMANAGER_DECLARE(postgresql);
+TNTDB_CONNECTIONMANAGER_DECLARE(postgresql)
 
 #endif // TNTDB_POSTGRESQL_IMPL_CONNECTIONMANAGER_H
 
