@@ -70,13 +70,14 @@ namespace tntdb
 
         cxxtools::Dynbuffer<const char*> paramValues;
         cxxtools::Dynbuffer<int> paramLengths;
+        cxxtools::Dynbuffer<int> paramFormats;
 
         // helper-methods for setting values
         template <typename T>
         void setValue(const std::string& col, T data);
 
         template <typename T>
-        void setStringValue(const std::string& col, T data);
+        void setStringValue(const std::string& col, T data, bool binary = false);
 
         template <typename T>
         void setIsoValue(const std::string& col, T data);
@@ -99,10 +100,16 @@ namespace tntdb
         void setBool(const std::string& col, bool data);
         void setInt(const std::string& col, int data);
         void setUnsigned(const std::string& col, unsigned data);
+        void setInt32(const std::string& col, int32_t data);
+        void setUnsigned32(const std::string& col, uint32_t data);
+        void setInt64(const std::string& col, int64_t data);
+        void setUnsigned64(const std::string& col, uint64_t data);
+        void setDecimal(const std::string& col, const Decimal& data);
         void setFloat(const std::string& col, float data);
         void setDouble(const std::string& col, double data);
         void setChar(const std::string& col, char data);
         void setString(const std::string& col, const std::string& data);
+        void setBlob(const std::string& col, const Blob& data);
         void setDate(const std::string& col, const Date& data);
         void setTime(const std::string& col, const Time& data);
         void setDatetime(const std::string& col, const Datetime& data);
@@ -118,6 +125,8 @@ namespace tntdb
         int getNParams()               { return values.size(); }
         const char* const* getParamValues();
         const int* getParamLengths();
+        const int* getParamFormats()
+            { return paramFormats.data(); }
         PGconn* getPGConn();
         Connection* getConnection()    { return conn; }
     };
