@@ -33,7 +33,7 @@ namespace tntdb
   }
 }
 
-TNTDB_CONNECTIONMANAGER_DECLARE(sqlite);
+TNTDB_CONNECTIONMANAGER_DECLARE(sqlite)
 
 #endif // TNTDB_SQLITE_IMPL_CONNECTIONMANAGER_H
 
