@@ -20,7 +20,6 @@
 #define TNTDB_SQLITE_IMPL_SQLSTATEMENT_H
 
 #include <tntdb/iface/istatement.h>
-#include <tntdb/smartptr.h>
 #include <sqlite3.h>
 
 namespace tntdb
@@ -53,10 +52,16 @@ namespace tntdb
         virtual void setBool(const std::string& col, bool data);
         virtual void setInt(const std::string& col, int data);
         virtual void setUnsigned(const std::string& col, unsigned data);
+        virtual void setInt32(const std::string& col, int32_t data);
+        virtual void setUnsigned32(const std::string& col, uint32_t data);
+        virtual void setInt64(const std::string& col, int64_t data);
+        virtual void setUnsigned64(const std::string& col, uint64_t data);
+        virtual void setDecimal(const std::string& col, const Decimal& data);
         virtual void setFloat(const std::string& col, float data);
         virtual void setDouble(const std::string& col, double data);
         virtual void setChar(const std::string& col, char data);
         virtual void setString(const std::string& col, const std::string& data);
+        virtual void setBlob(const std::string& col, const Blob& data);
         virtual void setDate(const std::string& col, const Date& data);
         virtual void setTime(const std::string& col, const Time& data);
         virtual void setDatetime(const std::string& col, const Datetime& data);
