@@ -38,7 +38,11 @@
 # include <tntdb/sqlite/impl/connectionmanager.h>
 #endif
 
-log_define("tntdb.connect");
+#ifdef WITH_STATIC_ORACLE
+# include <tntdb/oracle/connectionmanager.h>
+#endif
+
+log_define("tntdb.connect")
 
 namespace tntdb
 {
@@ -57,6 +61,8 @@ namespace tntdb
       return connectionManager_mysql.connect(url);
 #elif WITH_STATIC_SQLITE
       return connectionManager_sqlite.connect(url);
+#elif WITH_STATIC_ORACLE
+      return connectionManager_oracle.connect(url);
 #else
       throw Error("invalid url \"" + url + '"');
 #endif
@@ -71,6 +77,9 @@ namespace tntdb
 #elif WITH_STATIC_SQLITE
     if (driverName == "sqlite")
       return connectionManager_sqlite.connect(url.substr(n + 1));
+#elif WITH_STATIC_ORACLE
+    if (driverName == "oracle")
+      return connectionManager_oracle.connect(url.substr(n + 1));
 #endif
 
     std::string libraryUrl = url.substr(n + 1);
@@ -90,31 +99,31 @@ namespace tntdb
     return libraryManager.connect(libraryUrl);
   }
 
-  static ConnectionPool connectionPool;
+  static ConnectionPools connectionPools;
 
   Connection connectCached(const std::string& url)
   {
     log_debug("connectCached(\"" << url << "\")");
-    return connectionPool.connect(url);
+    return connectionPools.connect(url);
   }
 
   void dropCached(unsigned keep)
   {
-    connectionPool.drop(keep);
+    connectionPools.drop(keep);
   }
 
   void dropCached(const std::string& url, unsigned keep)
   {
-    connectionPool.drop(url, keep);
+    connectionPools.drop(url, keep);
   }
 
   void setMaxPoolSize(unsigned max)
   {
-    connectionPool.setMaxSize(max);
+    connectionPools.setMaximumSize(max);
   }
 
   unsigned getMaxPoolSize()
   {
-    return connectionPool.getMaxSize();
+    return connectionPools.getMaximumSize();
   }
 }
