@@ -19,7 +19,7 @@
 #include <tntdb/error.h>
 #include <cxxtools/log.h>
 
-log_define("tntdb.error");
+log_define("tntdb.error")
 
 namespace tntdb
 {
@@ -45,4 +45,10 @@ namespace tntdb
     : Error(msg),
       sql(sql_)
     { }
+
+  FieldNotFound::FieldNotFound(const std::string& field_)
+    : Error("field \"" + field_ + "\" not found"),
+      field(field_)
+  {
+  }
 }
