@@ -18,11 +18,14 @@
 
 #include <tntdb/mysql/bindutils.h>
 #include <tntdb/mysql/error.h>
+#include <tntdb/blob.h>
 #include <tntdb/date.h>
 #include <tntdb/time.h>
 #include <tntdb/datetime.h>
+#include <tntdb/decimal.h>
 #include <cxxtools/log.h>
 #include <sstream>
+#include <string.h>
 
 log_define("tntdb.mysql.bindutils")
 
@@ -93,6 +96,61 @@ namespace tntdb
           else
             return *static_cast<short int*>(bind.buffer);
 
+        case MYSQL_TYPE_INT24:
+        {
+          unsigned char* ptr = reinterpret_cast<unsigned char*>(bind.buffer);
+          if (bind.is_unsigned)
+          {
+#if __BYTE_ORDER == __LITTLE_ENDIAN
+            return (static_cast<int_type>(ptr[0]))
+                 + (static_cast<int_type>(ptr[1]) << 8)
+                 + (static_cast<int_type>(ptr[2]) << 16);
+#else
+            return (static_cast<int_type>(ptr[2]))
+                 + (static_cast<int_type>(ptr[1]) << 8)
+                 + (static_cast<int_type>(ptr[0]) << 16);
+#endif
+          }
+          else
+          {
+#if __BYTE_ORDER == __LITTLE_ENDIAN
+            if (ptr[2] < 128)
+            {
+              return static_cast<int_type>(ptr[0])
+                  + (static_cast<int_type>(ptr[1]) << 8)
+                  + (static_cast<int_type>(ptr[2]) << 16);
+            }
+            else
+            {
+              int32_t val;
+              unsigned char* vptr = reinterpret_cast<unsigned char*>(&val);
+              vptr[0] = ptr[0];
+              vptr[1] = ptr[1];
+              vptr[2] = ptr[2];
+              vptr[3] = '\xff';
+              return static_cast<int_type>(val);
+            }
+#else
+            if (ptr[2] < 128)
+            {
+              return (static_cast<int_type>(ptr[2]))
+                   + (static_cast<int_type>(ptr[1]) << 8)
+                   + (static_cast<int_type>(ptr[0]) << 16);
+            }
+            else
+            {
+              int32_t val;
+              unsigned char* vptr = reinterpret_cast<unsigned char*>(&val);
+              vptr[0] = '\xff';
+              vptr[1] = ptr[0];
+              vptr[2] = ptr[1];
+              vptr[3] = ptr[2];
+              return static_cast<int_type>(val);
+            }
+#endif
+          }
+        }
+
         case MYSQL_TYPE_LONG:
           if (bind.is_unsigned)
             return *static_cast<unsigned int*>(bind.buffer);
@@ -105,6 +163,23 @@ namespace tntdb
           else
             return *static_cast<long long int*>(bind.buffer);
 
+        case MYSQL_TYPE_DECIMAL:
+        case MYSQL_TYPE_NEWDECIMAL:
+        {
+          std::string data(static_cast<char*>(bind.buffer), *bind.length);
+          log_debug("extract integer-type from decimal \"" << data << '"');
+          std::istringstream in(data);
+          Decimal decimal;
+          decimal.read(in);
+          if (in.eof() || !in.fail())
+          {
+            int_type ret = decimal.getInteger<int_type>();
+            return ret;
+          }
+          log_error("type-error in getInteger, type=" << bind.buffer_type);
+          throw TypeError("type-error in getInteger");
+        }
+          
         case MYSQL_TYPE_VAR_STRING:
         case MYSQL_TYPE_STRING:
         {
@@ -113,7 +188,7 @@ namespace tntdb
           std::istringstream in(data);
           int_type ret;
           in >> ret;
-          if (in)
+          if (in.eof() || !in.fail())
             return ret;
 
           // no break!!!
@@ -134,22 +209,10 @@ namespace tntdb
       switch (bind.buffer_type)
       {
         case MYSQL_TYPE_TINY:
-          if (bind.is_unsigned)
-            return *static_cast<unsigned char*>(bind.buffer);
-          else
-            return *static_cast<signed char*>(bind.buffer);
-
         case MYSQL_TYPE_SHORT:
-          if (bind.is_unsigned)
-            return *static_cast<unsigned short int*>(bind.buffer);
-          else
-            return *static_cast<short int*>(bind.buffer);
-
+        case MYSQL_TYPE_INT24:
         case MYSQL_TYPE_LONG:
-          if (bind.is_unsigned)
-            return *static_cast<unsigned int*>(bind.buffer);
-          else
-            return *static_cast<int*>(bind.buffer);
+          return getInteger<int>(bind);
 
         case MYSQL_TYPE_FLOAT:
           return *static_cast<float*>(bind.buffer);
@@ -165,7 +228,7 @@ namespace tntdb
           std::istringstream in(data);
           float_type ret;
           in >> ret;
-          if (in)
+          if (in.eof() || !in.fail())
             return ret;
 
           // no break!!!
@@ -201,6 +264,45 @@ namespace tntdb
       bind.is_unsigned = 1;
     }
 
+    void setInt32(MYSQL_BIND& bind, int32_t data)
+    {
+      setValue(bind, data, MYSQL_TYPE_LONG);
+      bind.is_unsigned = 0;
+    }
+
+    void setUnsigned32(MYSQL_BIND& bind, uint32_t data)
+    {
+      setValue(bind, data, MYSQL_TYPE_LONG);
+      bind.is_unsigned = 1;
+    }
+
+    void setInt64(MYSQL_BIND& bind, int64_t data)
+    {
+      setValue(bind, data, MYSQL_TYPE_LONGLONG);
+      bind.is_unsigned = 0;
+    }
+
+    void setUnsigned64(MYSQL_BIND& bind, uint64_t data)
+    {
+      setValue(bind, data, MYSQL_TYPE_LONGLONG);
+      bind.is_unsigned = 1;
+    }
+
+    void setDecimal(MYSQL_BIND& bind, unsigned long& length, const Decimal& data)
+    {
+      std::ostringstream ds;
+      ds.precision(24);
+      data.print(ds, Decimal::infinityLong);
+      std::string d = ds.str();
+      reserve(bind, d.size());
+      d.copy(static_cast<char*>(bind.buffer), d.size());
+      bind.buffer_type = MYSQL_TYPE_NEWDECIMAL;
+      bind.is_null = 0;
+      length = d.size();
+      bind.length = &length;
+      bind.is_unsigned = 0;
+    }
+
     void setFloat(MYSQL_BIND& bind, float data)
     {
       setValue(bind, data, MYSQL_TYPE_FLOAT);
@@ -222,6 +324,17 @@ namespace tntdb
       reserve(bind, length + 1);
       memcpy(static_cast<char*>(bind.buffer), data, length + 1);
 
+      bind.buffer_type = MYSQL_TYPE_BLOB;
+      bind.is_null = 0;
+      bind.length = &length;
+    }
+
+    void setBlob(MYSQL_BIND& bind, unsigned long& length, const Blob& data)
+    {
+      length = data.size();
+      reserve(bind, length);
+      memcpy(static_cast<char*>(bind.buffer), data.data(), length);
+
       bind.buffer_type = MYSQL_TYPE_VAR_STRING;
       bind.is_null = 0;
       bind.length = &length;
@@ -310,6 +423,74 @@ namespace tntdb
       return getInteger<long>(bind);
     }
 
+    int32_t getInt32(const MYSQL_BIND& bind)
+    {
+      return getInteger<int32_t>(bind);
+    }
+
+    uint32_t getUnsigned32(const MYSQL_BIND& bind)
+    {
+      return getInteger<uint32_t>(bind);
+    }
+
+    int64_t getInt64(const MYSQL_BIND& bind)
+    {
+      return getInteger<int64_t>(bind);
+    }
+
+    uint64_t getUnsigned64(const MYSQL_BIND& bind)
+    {
+      return getInteger<uint64_t>(bind);
+    }
+
+    Decimal getDecimal(const MYSQL_BIND& bind)
+    {
+      if (isNull(bind))
+        throw NullValue();
+
+      switch (bind.buffer_type)
+      {
+        case MYSQL_TYPE_TINY:
+        case MYSQL_TYPE_SHORT:
+        case MYSQL_TYPE_INT24:
+        case MYSQL_TYPE_LONG:
+        case MYSQL_TYPE_LONGLONG:
+        {
+          int64_t i = getInteger<int64_t>(bind);
+          Decimal d(i);
+          return d;
+        }
+
+        case MYSQL_TYPE_FLOAT:
+        case MYSQL_TYPE_DOUBLE:
+        {
+          double f = getFloat<double>(bind);
+          Decimal d(f);
+          return d;
+        }
+          
+        case MYSQL_TYPE_DECIMAL:
+        case MYSQL_TYPE_NEWDECIMAL:
+        case MYSQL_TYPE_VAR_STRING:
+        case MYSQL_TYPE_STRING:
+        {
+          std::string data(static_cast<char*>(bind.buffer), *bind.length);
+          log_debug("extract Decimal from string \"" << data << '"');
+          std::istringstream in(data);
+          Decimal ret;
+          in >> ret;
+          if (in.eof() || !in.fail())
+            return ret;
+
+          // no break!!!
+        }
+
+        default:
+          log_error("type-error in getDecimal, type=" << bind.buffer_type);
+          throw TypeError("type-error in getDecimal");
+      }
+    }
+
     float getFloat(const MYSQL_BIND& bind)
     {
       return getFloat<float>(bind);
@@ -345,7 +526,7 @@ namespace tntdb
       }
     }
 
-    std::string getString(const MYSQL_BIND& bind)
+    void getString(const MYSQL_BIND& bind, std::string& ret)
     {
       if (isNull(bind))
         throw NullValue();
@@ -358,79 +539,97 @@ namespace tntdb
         case MYSQL_TYPE_BLOB:
         case MYSQL_TYPE_MEDIUM_BLOB:
         case MYSQL_TYPE_LONG_BLOB:
-          return std::string(static_cast<const char*>(bind.buffer),
+        case MYSQL_TYPE_DECIMAL:
+        case MYSQL_TYPE_NEWDECIMAL:
+          ret.assign(static_cast<const char*>(bind.buffer),
                              *bind.length);
+          break;
 
         case MYSQL_TYPE_DATE:
         {
           MYSQL_TIME* ts = static_cast<MYSQL_TIME*>(bind.buffer);
-          return Date(ts->year, ts->month, ts->day).getIso();
+          ret.assign(Date(ts->year, ts->month, ts->day).getIso());
+          break;
         }
 
         case MYSQL_TYPE_TIME:
         {
           MYSQL_TIME* ts = static_cast<MYSQL_TIME*>(bind.buffer);
-          return Time(ts->hour, ts->minute, ts->second).getIso();
+          ret.assign(Time(ts->hour, ts->minute, ts->second).getIso());
+          break;
         }
 
         case MYSQL_TYPE_DATETIME:
         case MYSQL_TYPE_TIMESTAMP:
         {
           MYSQL_TIME* ts = static_cast<MYSQL_TIME*>(bind.buffer);
-          return Datetime(ts->year, ts->month, ts->day,
-                          ts->hour, ts->minute, ts->second, ts->second_part).getIso();
+          ret.assign(Datetime(ts->year, ts->month, ts->day,
+                          ts->hour, ts->minute, ts->second, ts->second_part).getIso());
+          break;
         }
 
         default:
         {
-          std::ostringstream ret;
+          std::ostringstream s;
           switch (bind.buffer_type)
           {
             case MYSQL_TYPE_TINY:
-              if (bind.is_unsigned)
-                ret << static_cast<unsigned>(*static_cast<unsigned char*>(bind.buffer));
-              else
-                ret << static_cast<int>(*static_cast<signed char*>(bind.buffer));
-              break;
-
             case MYSQL_TYPE_SHORT:
-              if (bind.is_unsigned)
-                ret << *static_cast<unsigned short int*>(bind.buffer);
-              else
-                ret << *static_cast<short int*>(bind.buffer);
-              break;
-
+            case MYSQL_TYPE_INT24:
             case MYSQL_TYPE_LONG:
               if (bind.is_unsigned)
-                ret << *static_cast<unsigned int*>(bind.buffer);
+                s << getInteger<unsigned int>(bind);
               else
-                ret << *static_cast<int*>(bind.buffer);
+                s << getInteger<int>(bind);
               break;
 
             case MYSQL_TYPE_LONGLONG:
               if (bind.is_unsigned)
-                ret << *static_cast<long long unsigned*>(bind.buffer);
+                s << *static_cast<long long unsigned*>(bind.buffer);
               else
-                ret << *static_cast<long long int*>(bind.buffer);
+                s << *static_cast<long long int*>(bind.buffer);
               break;
 
             case MYSQL_TYPE_FLOAT:
-              ret << *static_cast<float*>(bind.buffer);
+              s << *static_cast<float*>(bind.buffer);
               break;
 
             case MYSQL_TYPE_DOUBLE:
-              ret << *static_cast<double*>(bind.buffer);
+              s << *static_cast<double*>(bind.buffer);
               break;
 
             default:
               log_error("type-error in getString, type=" << bind.buffer_type);
               throw TypeError("type-error in getString");
           }
-          return ret.str();
+          ret.assign(s.str());
         }
       }
     }
 
+    void getBlob(const MYSQL_BIND& bind, Blob& ret)
+    {
+      if (isNull(bind))
+        throw NullValue();
+
+      switch (bind.buffer_type)
+      {
+        case MYSQL_TYPE_STRING:
+        case MYSQL_TYPE_VAR_STRING:
+        case MYSQL_TYPE_TINY_BLOB:
+        case MYSQL_TYPE_BLOB:
+        case MYSQL_TYPE_MEDIUM_BLOB:
+        case MYSQL_TYPE_LONG_BLOB:
+          ret.assign(static_cast<const char*>(bind.buffer),
+                             *bind.length);
+          break;
+
+        default:
+          log_error("type-error in getBlob, type=" << bind.buffer_type);
+          throw TypeError("type-error in getBlob");
+      }
+    }
+
     Date getDate(const MYSQL_BIND& bind)
     {
       if (isNull(bind))
