@@ -21,7 +21,7 @@
 #include <tntdb/connection.h>
 #include <cxxtools/log.h>
 
-log_define("tntdb.postgresql.connectionmanager");
+log_define("tntdb.postgresql.connectionmanager")
 
 namespace tntdb
 {
@@ -34,4 +34,4 @@ namespace tntdb
   }
 }
 
-TNTDB_CONNECTIONMANAGER_DEFINE(postgresql);
+TNTDB_CONNECTIONMANAGER_DEFINE(postgresql)
