@@ -30,7 +30,7 @@
 #include <cxxtools/log.h>
 #include "config.h"
 
-log_define("tntdb.postgresql.statement");
+log_define("tntdb.postgresql.statement")
 
 #ifdef HAVE_PQPREPARE
 #  define SET_TYPE(pos, type)
@@ -95,6 +95,7 @@ namespace tntdb
 
       paramValues.reserve(se.getMaxIdx());
       paramLengths.reserve(se.getMaxIdx());
+      paramFormats.reserve(se.getMaxIdx());
     }
 
     Statement::~Statement()
@@ -163,9 +164,9 @@ namespace tntdb
         doPrepare();
 
       log_debug("PQexecPrepared(" << getPGConn() << ", \"" << stmtName
-        << "\", " << values.size() << ", paramValues, paramLengths, 0, 0)");
+        << "\", " << values.size() << ", paramValues, paramLengths, paramFormats, 0)");
       PGresult* result = PQexecPrepared(getPGConn(), stmtName.c_str(),
-        getNParams(), getParamValues(), getParamLengths(), 0, 0);
+        getNParams(), getParamValues(), getParamLengths(), getParamFormats(), 0);
 
       if (isError(result))
       {
@@ -187,17 +188,69 @@ namespace tntdb
         std::ostringstream v;
         v << data;
         values[it->second].setValue(v.str());
+        paramFormats[it->second] = 0;
       }
     }
 
-    template <typename T>
-    void Statement::setStringValue(const std::string& col, T data)
+    template <>
+    void Statement::setValue(const std::string& col, float data)
     {
       hostvarMapType::const_iterator it = hostvarMap.find(col);
       if (it == hostvarMap.end())
         log_warn("hostvariable :" << col << " not found");
       else
+      {
+        std::ostringstream v;
+        v.precision(24);
+        v << data;
+        values[it->second].setValue(v.str());
+        paramFormats[it->second] = 0;
+      }
+    }
+
+    template <>
+    void Statement::setValue(const std::string& col, double data)
+    {
+      hostvarMapType::const_iterator it = hostvarMap.find(col);
+      if (it == hostvarMap.end())
+        log_warn("hostvariable :" << col << " not found");
+      else
+      {
+        std::ostringstream v;
+        v.precision(24);
+        v << data;
+        values[it->second].setValue(v.str());
+        paramFormats[it->second] = 0;
+      }
+    }
+
+    template <>
+    void Statement::setValue(const std::string& col, Decimal data)
+    {
+      hostvarMapType::const_iterator it = hostvarMap.find(col);
+      if (it == hostvarMap.end())
+        log_warn("hostvariable :" << col << " not found");
+      else
+      {
+        std::ostringstream v;
+        v.precision(24);
+        v << data;
+        values[it->second].setValue(v.str());
+        paramFormats[it->second] = 0;
+      }
+    }
+    
+    template <typename T>
+    void Statement::setStringValue(const std::string& col, T data, bool binary)
+    {
+      hostvarMapType::const_iterator it = hostvarMap.find(col);
+      if (it == hostvarMap.end())
+        log_warn("hostvariable :" << col << " not found");
+      else
+      {
         values[it->second].setValue(data);
+        paramFormats[it->second] = binary;
+      }
     }
 
     template <typename T>
@@ -207,7 +260,10 @@ namespace tntdb
       if (it == hostvarMap.end())
         log_warn("hostvariable :" << col << " not found");
       else
+      {
         values[it->second].setValue(data.getIso());
+        paramFormats[it->second] = 0;
+      }
     }
 
 #ifndef HAVE_PQPREPARE
@@ -264,6 +320,41 @@ namespace tntdb
       SET_TYPE(col, "int");
     }
 
+    void Statement::setInt32(const std::string& col, int32_t data)
+    {
+      log_debug("setInt32(\"" << col << "\", " << data << ')');
+      setValue(col, data);
+      SET_TYPE(col, "int");
+    }
+
+    void Statement::setUnsigned32(const std::string& col, uint32_t data)
+    {
+      log_debug("setUnsigned32(\"" << col << "\", " << data << ')');
+      setValue(col, data);
+      SET_TYPE(col, "int");
+    }
+    
+    void Statement::setInt64(const std::string& col, int64_t data)
+    {
+      log_debug("setInt64(\"" << col << "\", " << data << ')');
+      setValue(col, data);
+      SET_TYPE(col, "bigint");
+    }
+
+    void Statement::setUnsigned64(const std::string& col, uint64_t data)
+    {
+      log_debug("setUnsigned64(\"" << col << "\", " << data << ')');
+      setValue(col, data);
+      SET_TYPE(col, "bigint");
+    }
+
+    void Statement::setDecimal(const std::string& col, const Decimal& data)
+    {
+      log_debug("setDecimal(\"" << col << "\", " << data << ')');
+      setValue(col, data);
+      SET_TYPE(col, "numeric");
+    }
+    
     void Statement::setFloat(const std::string& col, float data)
     {
       log_debug("setFloat(\"" << col << "\", " << data << ')');
@@ -292,6 +383,13 @@ namespace tntdb
       SET_TYPE(col, "text");
     }
 
+    void Statement::setBlob(const std::string& col, const Blob& data)
+    {
+      log_debug("setBlob(\"" << col << "\", Blob)");
+      setStringValue(col, std::string(data.data(), data.size()), true);
+      SET_TYPE(col, "blob");
+    }
+
     void Statement::setDate(const std::string& col, const Date& data)
     {
       log_debug("setDate(\"" << col << "\", " << data.getIso() << ')');
