@@ -30,9 +30,10 @@
 #include <tntdb/row.h>
 #include <tntdb/value.h>
 #include <sstream>
+#include <limits>
 #include <cxxtools/log.h>
 
-log_define("tntdb.sqlite.statement");
+log_define("tntdb.sqlite.statement")
 
 namespace tntdb
 {
@@ -114,6 +115,9 @@ namespace tntdb
         // we have already a new statement-handle - destroy the old one
         log_debug("sqlite3_finalize(" << stmt_ << ')');
         ::sqlite3_finalize(stmt_);
+
+        if (stmtInUse == stmt_)
+          stmtInUse = 0;
       }
     }
 
@@ -196,6 +200,11 @@ namespace tntdb
       }
     }
 
+    void Statement::setInt32(const std::string& col, int32_t data)
+    {
+      setInt(col, data);
+    }
+    
     void Statement::setUnsigned(const std::string& col, unsigned data)
     {
       if (data > static_cast<unsigned>(std::numeric_limits<int>::max()))
@@ -208,6 +217,47 @@ namespace tntdb
         setInt(col, static_cast<int>(data));
     }
 
+    void Statement::setUnsigned32(const std::string& col, uint32_t data)
+    {
+      setUnsigned(col, data);
+    }
+
+    void Statement::setInt64(const std::string& col, int64_t data)
+    {
+      int idx = getBindIndex(col);
+      sqlite3_stmt* stmt = getBindStmt();
+      if (idx != 0)
+      {
+        reset();
+
+        log_debug("sqlite3_bind_int64(" << stmt << ", " << idx << ')');
+        int ret = ::sqlite3_bind_int64(stmt, idx, data);
+
+        if (ret != SQLITE_OK)
+          throw Execerror("sqlite3_bind_int64", stmt, ret);
+      }
+    }
+    
+    void Statement::setUnsigned64(const std::string& col, uint64_t data)
+    {
+      setInt64(col, (int64_t)data);
+    }
+    
+    void Statement::setDecimal(const std::string& col, const Decimal& data)
+    {
+      // SQLite 3.4.1 does not support the SQL decimal or numeric types.
+      // So double is used instead, but of course binary floating point can
+      // not accurately store decimal floating point numbers.
+      // Maybe we could try instead using:
+      // int sqlite3_value_numeric_type(sqlite3_value*);
+      // However I do not understand the SQLite 3.4.1 documentation
+      // for this API.  I am confused by how it only returns an int,
+      // yet the API documentation talks about returning an int, double
+      // or text string.
+      double d = data.getDouble();
+      setDouble(col, d);
+    }
+    
     void Statement::setFloat(const std::string& col, float data)
     {
       setDouble(col, static_cast<double>(data));
@@ -254,9 +304,26 @@ namespace tntdb
       {
         reset();
 
-        log_debug("sqlite3_bind_blob(" << stmt << ", " << idx << ", " << data
+        log_debug("sqlite3_bind_text(" << stmt << ", " << idx << ", " << data
           << ", " << data.size() << ", SQLITE_TRANSIENT)");
-        int ret = ::sqlite3_bind_blob(stmt, idx, data.c_str(), data.size(), SQLITE_TRANSIENT);
+        int ret = ::sqlite3_bind_text(stmt, idx, data.data(), data.size(), SQLITE_TRANSIENT);
+
+        if (ret != SQLITE_OK)
+          throw Execerror("sqlite3_bind_text", stmt, ret);
+      }
+    }
+
+    void Statement::setBlob(const std::string& col, const Blob& data)
+    {
+      int idx = getBindIndex(col);
+      sqlite3_stmt* stmt = getBindStmt();
+      if (idx != 0)
+      {
+        reset();
+
+        log_debug("sqlite3_bind_blob(" << stmt << ", " << idx << ", data, "
+            << data.size() << ", SQLITE_TRANSIENT)");
+        int ret = ::sqlite3_bind_blob(stmt, idx, data.data(), data.size(), SQLITE_TRANSIENT);
 
         if (ret != SQLITE_OK)
           throw Execerror("sqlite3_bind_blob", stmt, ret);
@@ -328,13 +395,25 @@ namespace tntdb
             log_debug("sqlite3_column_bytes(" << stmt << ", " << i << ')');
             int n = sqlite3_column_bytes(stmt, i);
 
-            log_debug("sqlite3_column_blob(" << stmt << ", " << i << ')');
-            const void* txt = sqlite3_column_blob(stmt, i);
+            const void* txt = 0;
+
+            if (n > 0)
+            {
+              log_debug("sqlite3_column_blob(" << stmt << ", " << i << ')');
+              txt = sqlite3_column_blob(stmt, i);
+            }
+
             Value v;
             if (txt)
               v = Value(new ValueImpl(
                 std::string(static_cast<const char*>(txt), n)));
-            row->add(v);
+
+            log_debug("sqlite3_column_name(" << stmt << ", " << i << ')');
+            const char* name = sqlite3_column_name(stmt, i);
+            if (name == 0)
+              throw std::bad_alloc();
+
+            row->add(name, v);
           }
         }
         else if (ret != SQLITE_DONE)
@@ -372,13 +451,25 @@ namespace tntdb
           log_debug("sqlite3_column_bytes(" << stmt << ", " << i << ')');
           int n = sqlite3_column_bytes(stmt, i);
 
-          log_debug("sqlite3_column_blob(" << stmt << ", " << i << ')');
-          const void* txt = sqlite3_column_blob(stmt, i);
+          const void* txt = 0;
+
+          if (n > 0)
+          {
+            log_debug("sqlite3_column_blob(" << stmt << ", " << i << ')');
+            txt = sqlite3_column_blob(stmt, i);
+          }
+
           Value v;
           if (txt)
             v = Value(new ValueImpl(
               std::string(static_cast<const char*>(txt), n)));
-          r->add(v);
+
+          log_debug("sqlite3_column_name(" << stmt << ", " << i << ')');
+          const char* name = sqlite3_column_name(stmt, i);
+          if (name == 0)
+            throw std::bad_alloc();
+
+          r->add(name, v);
         }
         return row;
       }
@@ -418,8 +509,14 @@ namespace tntdb
         log_debug("sqlite3_column_bytes(" << stmt << ", 0)");
         int n = sqlite3_column_bytes(stmt, 0);
 
-        log_debug("sqlite3_column_blob(" << stmt << ", 0)");
-        const void* txt = sqlite3_column_blob(stmt, 0);
+        const void* txt = 0;
+
+        if (n > 0)
+        {
+          log_debug("sqlite3_column_blob(" << stmt << ", 0)");
+          txt = sqlite3_column_blob(stmt, 0);
+        }
+
         Value v;
         if (txt)
           v = Value(new ValueImpl(
