@@ -21,7 +21,7 @@
 #include <tntdb/value.h>
 #include <cxxtools/log.h>
 
-log_define("tntdb.sqlite.stmtrow");
+log_define("tntdb.sqlite.stmtrow")
 
 namespace tntdb
 {
@@ -32,10 +32,15 @@ namespace tntdb
       return static_cast<unsigned>(::sqlite3_column_count(stmt));
     }
 
-    Value StmtRow::getValue(size_type field_num) const
+    Value StmtRow::getValueByNumber(size_type field_num) const
     {
       return Value(new StmtValue(stmt, field_num));
     }
 
+    Value StmtRow::getValueByName(const std::string& field_name) const
+    {
+      return Value(new StmtValue(stmt, field_name));
+    }
+
   }
 }
